@@ -4,11 +4,12 @@ from django.views.generic import TemplateView
 from django.contrib import admin
 admin.autodiscover()
 
-urlpatterns = patterns('',
+urlpatterns = patterns('',  # NOQA
 
     url(r'^$', TemplateView.as_view(
         template_name='app/home.html'), name='home'),
     url(r'^pizzagigi/', include('pizzagigi.urls', namespace='pizza')),
+    url(r'^forthewing/', include('forthewing.urls', namespace='ftw')),
 
     url(r'^i18n/', include('django.conf.urls.i18n')),
 
